AudioNotification class

Constructors

AudioNotification({required String smallIconFileName, String? title, String? subTitle = "", String? largeIconUrl = "", bool isLocal = false, NotificationDefaultActions notificationDefaultActions = NotificationDefaultActions.ALL, NotificationActionCallbackMode notificationActionCallbackMode = NotificationActionCallbackMode.DEFAULT, NotificationCustomActions notificationCustomActions = NotificationCustomActions.DISABLED})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isLocal → bool
final
largeIconUrl → String?
final
notificationActionCallbackMode → NotificationActionCallbackMode
final
notificationCustomActions → NotificationCustomActions
final
notificationDefaultActions → NotificationDefaultActions
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
smallIconFileName → String
final
subTitle → String?
final
title → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited